@@ -9,7 +9,7 @@ use Exporter ();
 # @EXPORT_OK/%EXPORT_TAGS are set up in XS
 *import = \&Exporter::import;
 
-our $VERSION = '0.41_02'; # TRIAL VERSION
+our $VERSION = '0.41_03'; # TRIAL VERSION
 
 XSLoader::load(__PACKAGE__);
 
@@ -74,6 +74,12 @@ sub _dump {
     Data::Dumper::Dumper(@_)
 }
 
+sub _stack_trace {
+    my (undef, $filename, $line) = caller(0);
+
+    return "$filename line $line";
+}
+
 1;
 
 __END__
@@ -88,7 +94,7 @@ Google::ProtocolBuffers::Dynamic - fast and complete protocol buffer implementat
 
 =head1 VERSION
 
-version 0.41_02
+version 0.41_03
 
 =head1 SYNOPSIS
 
@@ -558,6 +564,11 @@ Maps C<true> to C<1> and C<false> to C<"">.
 
 Maps C<true> to C<1> and C<false> to C<0>.
 
+=item json
+
+Loads L<JSON> and uses C<JSON::true> and C<JSON::false> as
+C<true>/C<false> values.
+
 =back
 
 =head2 check_required_fields
